window.Gleam.initSearch([{"doc":"shimmer","title":"shimmer","content":"# Shimmer\n\nA Gleam library for interacting with the Discord API\n\n&gt; **Warning**\n&gt; This Library is pre-alpha and being worked on.\n\n## Talks\n- [FOSDEM 2023](https://fosdem.org/2023/schedule/event/beam_gleam_intro/) ([Harry Bairstow](https://github.com/HarryET))\n\n## Basic Example\n\n```\nshimmer = &quot;~&gt; 0.0.6&quot;\ngleam_stdlib = &quot;~&gt; 0.25&quot;\ngleam_erlang = &quot;~&gt; 0.17&quot;\n```\n\n```gleam\nimport gleam/io\nimport gleam/string\nimport gleam/int\nimport gleam/erlang/process\nimport shimmer\nimport shimmer/handlers\n\npub fn main() {\n  let handlers =\n    handlers.new_builder()\n    |&gt; handlers.on_ready(fn(data, _client) {\n      io.println(\n        [\n          &quot;Logged in as &quot;,\n          data.user.username,\n          &quot; (&quot;,\n          int.to_string(data.user.id),\n          &quot;)&quot;,\n        ]\n        |&gt; string.join(with: &quot;&quot;),\n      )\n    })\n    |&gt; handlers.on_message(fn(message, _client) { io.print(&quot;Received: &quot; &lt;&gt; message) })\n\n  let client =\n    shimmer.new(&quot;TOKEN&quot;)\n    |&gt; shimmer.connect(handlers)\n\n  process.sleep_forever()\n}\n```\n\n## Supported Events\n- [x] Ready\n- [ ] Resumed\n- [ ] Channel Create\n- [ ] Channel Update\n- [ ] Channel Delete\n- [ ] Channel Pins Update\n- [ ] Guild Create\n- [ ] Guild Update\n- [ ] Guild Delete\n- [ ] Guild Ban Add\n- [ ] Guild Ban Remove\n- [ ] Guild Emoji Update\n- [ ] Guild Integrations Update\n- [ ] Guild Member Add\n- [ ] Guild Member Remove\n- [ ] Guild Member Update\n- [ ] Guild Members Chunk\n- [ ] Guild Role Create\n- [ ] Guild Role Update\n- [ ] Guild Role Delete\n- [ ] Invite Create\n- [ ] Invite Delete\n- [x] Message Create\n- [ ] Message Update\n- [ ] Message Delete\n- [ ] Message Delete Bulk\n- [ ] Message Reaction Add\n- [ ] Message Reaction Remove\n- [ ] Message Reaction Remove All\n- [ ] Message Reaction Remove Emoji\n- [ ] Presence Update\n- [ ] Typing Start\n- [ ] User Update\n- [ ] Voice State Update\n- [ ] Voice Server Update\n- [ ] Webhooks Update\n","url":"index.html"},{"doc":"shimmer/snowflake","title":"Snowflake","content":"pub type Snowflake =\n  String\n\n\nSynonyms:\nshimmer/snowflake.Snowflake\nshimmer/snowflake Snowflake","url":"shimmer/snowflake.html#Snowflake"},{"doc":"shimmer/snowflake","title":"from_dynamic","content":"pub fn from_dynamic(dyn: Dynamic) -&gt; Result(\n  String,\n  List(DecodeError),\n)\n\nSynonyms:\nshimmer/snowflake.from_dynamic\nshimmer/snowflake from_dynamic","url":"shimmer/snowflake.html#from_dynamic"},{"doc":"shimmer/snowflake","title":"shimmer/snowflake","content":"","url":"shimmer/snowflake.html"},{"doc":"shimmer/types/emoji","title":"Emoji","content":"pub type Emoji {\n  UnicodeEmoji(emoji: String)\n  CustomEmoji(id: Snowflake, name: String, animated: Bool)\n}\n\nUnicodeEmoji(emoji: String)\n\n\nCustomEmoji(id: Snowflake, name: String, animated: Bool)\n\n\nSynonyms:\nshimmer/types/emoji.Emoji\nshimmer/types/emoji Emoji","url":"shimmer/types/emoji.html#Emoji"},{"doc":"shimmer/types/emoji","title":"encode","content":"pub fn encode(self: Emoji) -&gt; String\n\nSynonyms:\nshimmer/types/emoji.encode\nshimmer/types/emoji encode","url":"shimmer/types/emoji.html#encode"},{"doc":"shimmer/types/emoji","title":"to_map","content":"pub fn to_map(self: Emoji) -&gt; Map(String, Dynamic)\n\nSynonyms:\nshimmer/types/emoji.to_map\nshimmer/types/emoji to_map","url":"shimmer/types/emoji.html#to_map"},{"doc":"shimmer/types/emoji","title":"shimmer/types/emoji","content":"","url":"shimmer/types/emoji.html"},{"doc":"shimmer/types/presence","title":"Presence","content":"pub type Presence {\n  Presence(\n    status: PresenceStatus,\n    activities: List(PresenceActivity),\n    since: Option(Int),\n    afk: Bool,\n  )\n}\n\nPresence(\n  status: PresenceStatus,\n  activities: List(PresenceActivity),\n  since: Option(Int),\n  afk: Bool,\n)\n\n\nSynonyms:\nshimmer/types/presence.Presence\nshimmer/types/presence Presence","url":"shimmer/types/presence.html#Presence"},{"doc":"shimmer/types/presence","title":"PresenceActivity","content":"pub type PresenceActivity {\n  PresenceActivity(\n    name: String,\n    type_: PresenceActivityType,\n    url: Option(String),\n    created_at: Int,\n    timestamps: Option(PresenceActivityTimestamps),\n    application_id: Option(String),\n    details: Option(String),\n    state: Option(String),\n    emoji: Option(Emoji),\n    party: Option(PresenceActivityParty),\n    assets: Option(PresenceActivityAssets),\n    secrets: Option(PresenceActivitySecrets),\n    instance: Option(Bool),\n    flags: Option(List(PresenceActivityFlags)),\n    buttons: Option(List(PresenceActivityButton)),\n  )\n}\n\nPresenceActivity(\n  name: String,\n  type_: PresenceActivityType,\n  url: Option(String),\n  created_at: Int,\n  timestamps: Option(PresenceActivityTimestamps),\n  application_id: Option(String),\n  details: Option(String),\n  state: Option(String),\n  emoji: Option(Emoji),\n  party: Option(PresenceActivityParty),\n  assets: Option(PresenceActivityAssets),\n  secrets: Option(PresenceActivitySecrets),\n  instance: Option(Bool),\n  flags: Option(List(PresenceActivityFlags)),\n  buttons: Option(List(PresenceActivityButton)),\n)\n\n\nSynonyms:\nshimmer/types/presence.PresenceActivity\nshimmer/types/presence PresenceActivity","url":"shimmer/types/presence.html#PresenceActivity"},{"doc":"shimmer/types/presence","title":"PresenceActivityAssets","content":"pub type PresenceActivityAssets {\n  PresenceActivityAssets(\n    large_image: Option(String),\n    large_text: Option(String),\n    small_image: Option(String),\n    small_text: Option(String),\n  )\n}\n\nPresenceActivityAssets(\n  large_image: Option(String),\n  large_text: Option(String),\n  small_image: Option(String),\n  small_text: Option(String),\n)\n\n\nSynonyms:\nshimmer/types/presence.PresenceActivityAssets\nshimmer/types/presence PresenceActivityAssets","url":"shimmer/types/presence.html#PresenceActivityAssets"},{"doc":"shimmer/types/presence","title":"PresenceActivityButton","content":"pub type PresenceActivityButton {\n  PresenceActivityButton(label: String, url: String)\n}\n\nPresenceActivityButton(label: String, url: String)\n\n\nSynonyms:\nshimmer/types/presence.PresenceActivityButton\nshimmer/types/presence PresenceActivityButton","url":"shimmer/types/presence.html#PresenceActivityButton"},{"doc":"shimmer/types/presence","title":"PresenceActivityFlags","content":"pub type PresenceActivityFlags {\n  Instace\n  Join\n  Spectate\n  JoinRequest\n  Sync\n  Play\n  PartyPrivacyFriends\n  PartyPrivacyVoiceChannel\n  Embedded\n}\n\nInstace\n\n\nJoin\n\n\nSpectate\n\n\nJoinRequest\n\n\nSync\n\n\nPlay\n\n\nPartyPrivacyFriends\n\n\nPartyPrivacyVoiceChannel\n\n\nEmbedded\n\n\nSynonyms:\nshimmer/types/presence.PresenceActivityFlags\nshimmer/types/presence PresenceActivityFlags","url":"shimmer/types/presence.html#PresenceActivityFlags"},{"doc":"shimmer/types/presence","title":"PresenceActivityParty","content":"pub type PresenceActivityParty {\n  PresenceActivityParty(\n    id: Option(String),\n    max_size: Option(Int),\n    current_size: Option(Int),\n  )\n}\n\nPresenceActivityParty(\n  id: Option(String),\n  max_size: Option(Int),\n  current_size: Option(Int),\n)\n\n\nSynonyms:\nshimmer/types/presence.PresenceActivityParty\nshimmer/types/presence PresenceActivityParty","url":"shimmer/types/presence.html#PresenceActivityParty"},{"doc":"shimmer/types/presence","title":"PresenceActivitySecrets","content":"pub type PresenceActivitySecrets {\n  PresenceActivitySecrets(\n    join: Option(String),\n    spectate: Option(String),\n    match_: Option(String),\n  )\n}\n\nPresenceActivitySecrets(\n  join: Option(String),\n  spectate: Option(String),\n  match_: Option(String),\n)\n\n\nSynonyms:\nshimmer/types/presence.PresenceActivitySecrets\nshimmer/types/presence PresenceActivitySecrets","url":"shimmer/types/presence.html#PresenceActivitySecrets"},{"doc":"shimmer/types/presence","title":"PresenceActivityTimestamps","content":"pub type PresenceActivityTimestamps {\n  PresenceActivityTimestamps(\n    start: Option(Int),\n    end: Option(Int),\n  )\n}\n\nPresenceActivityTimestamps(start: Option(Int), end: Option(Int))\n\n\nSynonyms:\nshimmer/types/presence.PresenceActivityTimestamps\nshimmer/types/presence PresenceActivityTimestamps","url":"shimmer/types/presence.html#PresenceActivityTimestamps"},{"doc":"shimmer/types/presence","title":"PresenceActivityType","content":"pub type PresenceActivityType {\n  Game\n  Streaming\n  Listening\n  Custom\n  Competing\n}\n\nGame\n Game\n\nStreaming\n Streaming\n\nListening\n Listening to Spotify\n\nCustom\n Custom status\n\nCompeting\n Competing in a game\n\nSynonyms:\nshimmer/types/presence.PresenceActivityType\nshimmer/types/presence PresenceActivityType","url":"shimmer/types/presence.html#PresenceActivityType"},{"doc":"shimmer/types/presence","title":"PresenceStatus","content":"pub type PresenceStatus {\n  Online\n  DoNotDisturb\n  Idle\n  Invisible\n  Offline\n}\n The status used in a Presence\nOnline\n Online\n\nDoNotDisturb\n Do Not Disturb\n\nIdle\n AFK\n\nInvisible\n Invisible and shown as offline\n\nOffline\n Offline\n\nSynonyms:\nshimmer/types/presence.PresenceStatus\nshimmer/types/presence PresenceStatus","url":"shimmer/types/presence.html#PresenceStatus"},{"doc":"shimmer/types/presence","title":"presence_activity_flag_to_int","content":"pub fn presence_activity_flag_to_int(flag: PresenceActivityFlags) -&gt; Int\n\nSynonyms:\nshimmer/types/presence.presence_activity_flag_to_int\nshimmer/types/presence presence_activity_flag_to_int","url":"shimmer/types/presence.html#presence_activity_flag_to_int"},{"doc":"shimmer/types/presence","title":"presence_activity_flags_to_int","content":"pub fn presence_activity_flags_to_int(flags: List(\n    PresenceActivityFlags,\n  )) -&gt; Int\n\nSynonyms:\nshimmer/types/presence.presence_activity_flags_to_int\nshimmer/types/presence presence_activity_flags_to_int","url":"shimmer/types/presence.html#presence_activity_flags_to_int"},{"doc":"shimmer/types/presence","title":"to_map","content":"pub fn to_map(self: Presence) -&gt; Map(String, Dynamic)\n\nSynonyms:\nshimmer/types/presence.to_map\nshimmer/types/presence to_map","url":"shimmer/types/presence.html#to_map"},{"doc":"shimmer/types/presence","title":"shimmer/types/presence","content":"","url":"shimmer/types/presence.html"},{"doc":"shimmer/internal/error","title":"ShimmerError","content":"pub type ShimmerError {\n  UnknownAccount\n  EmptyOptionWhenRequired\n  InvalidJson(json.DecodeError)\n  InvalidDynamicList(List(dynamic.DecodeError))\n  InvalidFormat(dynamic.DecodeError)\n  WebsocketError(Nil)\n  HttpError(hackney.Error)\n  ActorError(actor.StartError)\n  NilMapEntry(Nil)\n  BadBuilderProperties(String)\n}\n\nUnknownAccount\n\n\nEmptyOptionWhenRequired\n\n\nInvalidJson(json.DecodeError)\n\n\nInvalidDynamicList(List(dynamic.DecodeError))\n\n\nInvalidFormat(dynamic.DecodeError)\n\n\nWebsocketError(Nil)\n\n\nHttpError(hackney.Error)\n\n\nActorError(actor.StartError)\n\n\nNilMapEntry(Nil)\n\n\nBadBuilderProperties(String)\n Used when a builder dosen&#39;t have all of the properties it requires\n\nSynonyms:\nshimmer/internal/error.ShimmerError\nshimmer/internal/error ShimmerError","url":"shimmer/internal/error.html#ShimmerError"},{"doc":"shimmer/internal/error","title":"shimmer/internal/error","content":"","url":"shimmer/internal/error.html"},{"doc":"shimmer/builders/presence_activity_builder","title":"PresenceActivityBuilder","content":"pub type PresenceActivityBuilder {\n  PresenceActivityBuilder(\n    name: String,\n    type_: PresenceActivityType,\n    url: Option(String),\n    created_at: Option(Int),\n    timestamps: Option(PresenceActivityTimestamps),\n    application_id: Option(String),\n    details: Option(String),\n    state: Option(String),\n    emoji: Option(Emoji),\n    party: Option(PresenceActivityParty),\n    assets: Option(PresenceActivityAssets),\n    secrets: Option(PresenceActivitySecrets),\n    instance: Option(Bool),\n    flags: Option(List(PresenceActivityFlags)),\n    buttons: Option(List(PresenceActivityButton)),\n  )\n}\n\nPresenceActivityBuilder(\n  name: String,\n  type_: PresenceActivityType,\n  url: Option(String),\n  created_at: Option(Int),\n  timestamps: Option(PresenceActivityTimestamps),\n  application_id: Option(String),\n  details: Option(String),\n  state: Option(String),\n  emoji: Option(Emoji),\n  party: Option(PresenceActivityParty),\n  assets: Option(PresenceActivityAssets),\n  secrets: Option(PresenceActivitySecrets),\n  instance: Option(Bool),\n  flags: Option(List(PresenceActivityFlags)),\n  buttons: Option(List(PresenceActivityButton)),\n)\n\n\nSynonyms:\nshimmer/builders/presence_activity_builder.PresenceActivityBuilder\nshimmer/builders/presence_activity_builder PresenceActivityBuilder","url":"shimmer/builders/presence_activity_builder.html#PresenceActivityBuilder"},{"doc":"shimmer/builders/presence_activity_builder","title":"add_button","content":"pub fn add_button(self: PresenceActivityBuilder, button: PresenceActivityButton) -&gt; PresenceActivityBuilder\n\nSynonyms:\nshimmer/builders/presence_activity_builder.add_button\nshimmer/builders/presence_activity_builder add_button","url":"shimmer/builders/presence_activity_builder.html#add_button"},{"doc":"shimmer/builders/presence_activity_builder","title":"add_flag","content":"pub fn add_flag(self: PresenceActivityBuilder, flag: PresenceActivityFlags) -&gt; PresenceActivityBuilder\n\nSynonyms:\nshimmer/builders/presence_activity_builder.add_flag\nshimmer/builders/presence_activity_builder add_flag","url":"shimmer/builders/presence_activity_builder.html#add_flag"},{"doc":"shimmer/builders/presence_activity_builder","title":"build","content":"pub fn build(self: PresenceActivityBuilder) -&gt; Result(\n  PresenceActivity,\n  ShimmerError,\n)\n\nSynonyms:\nshimmer/builders/presence_activity_builder.build\nshimmer/builders/presence_activity_builder build","url":"shimmer/builders/presence_activity_builder.html#build"},{"doc":"shimmer/builders/presence_activity_builder","title":"new","content":"pub fn new(name: String, type_: PresenceActivityType) -&gt; PresenceActivityBuilder\n\nSynonyms:\nshimmer/builders/presence_activity_builder.new\nshimmer/builders/presence_activity_builder new","url":"shimmer/builders/presence_activity_builder.html#new"},{"doc":"shimmer/builders/presence_activity_builder","title":"set_application_id","content":"pub fn set_application_id(self: PresenceActivityBuilder, application_id: String) -&gt; PresenceActivityBuilder\n\nSynonyms:\nshimmer/builders/presence_activity_builder.set_application_id\nshimmer/builders/presence_activity_builder set_application_id","url":"shimmer/builders/presence_activity_builder.html#set_application_id"},{"doc":"shimmer/builders/presence_activity_builder","title":"set_assets","content":"pub fn set_assets(self: PresenceActivityBuilder, assets: PresenceActivityAssets) -&gt; PresenceActivityBuilder\n\nSynonyms:\nshimmer/builders/presence_activity_builder.set_assets\nshimmer/builders/presence_activity_builder set_assets","url":"shimmer/builders/presence_activity_builder.html#set_assets"},{"doc":"shimmer/builders/presence_activity_builder","title":"set_buttons","content":"pub fn set_buttons(self: PresenceActivityBuilder, buttons: List(\n    PresenceActivityButton,\n  )) -&gt; PresenceActivityBuilder\n\nSynonyms:\nshimmer/builders/presence_activity_builder.set_buttons\nshimmer/builders/presence_activity_builder set_buttons","url":"shimmer/builders/presence_activity_builder.html#set_buttons"},{"doc":"shimmer/builders/presence_activity_builder","title":"set_created_at","content":"pub fn set_created_at(self: PresenceActivityBuilder, created_at: Int) -&gt; PresenceActivityBuilder\n\nSynonyms:\nshimmer/builders/presence_activity_builder.set_created_at\nshimmer/builders/presence_activity_builder set_created_at","url":"shimmer/builders/presence_activity_builder.html#set_created_at"},{"doc":"shimmer/builders/presence_activity_builder","title":"set_details","content":"pub fn set_details(self: PresenceActivityBuilder, details: String) -&gt; PresenceActivityBuilder\n\nSynonyms:\nshimmer/builders/presence_activity_builder.set_details\nshimmer/builders/presence_activity_builder set_details","url":"shimmer/builders/presence_activity_builder.html#set_details"},{"doc":"shimmer/builders/presence_activity_builder","title":"set_emoji","content":"pub fn set_emoji(self: PresenceActivityBuilder, emoji: Emoji) -&gt; PresenceActivityBuilder\n\nSynonyms:\nshimmer/builders/presence_activity_builder.set_emoji\nshimmer/builders/presence_activity_builder set_emoji","url":"shimmer/builders/presence_activity_builder.html#set_emoji"},{"doc":"shimmer/builders/presence_activity_builder","title":"set_flags","content":"pub fn set_flags(self: PresenceActivityBuilder, flags: List(\n    PresenceActivityFlags,\n  )) -&gt; PresenceActivityBuilder\n\nSynonyms:\nshimmer/builders/presence_activity_builder.set_flags\nshimmer/builders/presence_activity_builder set_flags","url":"shimmer/builders/presence_activity_builder.html#set_flags"},{"doc":"shimmer/builders/presence_activity_builder","title":"set_instance","content":"pub fn set_instance(self: PresenceActivityBuilder, instance: Bool) -&gt; PresenceActivityBuilder\n\nSynonyms:\nshimmer/builders/presence_activity_builder.set_instance\nshimmer/builders/presence_activity_builder set_instance","url":"shimmer/builders/presence_activity_builder.html#set_instance"},{"doc":"shimmer/builders/presence_activity_builder","title":"set_name","content":"pub fn set_name(self: PresenceActivityBuilder, name: String) -&gt; PresenceActivityBuilder\n\nSynonyms:\nshimmer/builders/presence_activity_builder.set_name\nshimmer/builders/presence_activity_builder set_name","url":"shimmer/builders/presence_activity_builder.html#set_name"},{"doc":"shimmer/builders/presence_activity_builder","title":"set_party","content":"pub fn set_party(self: PresenceActivityBuilder, party: PresenceActivityParty) -&gt; PresenceActivityBuilder\n\nSynonyms:\nshimmer/builders/presence_activity_builder.set_party\nshimmer/builders/presence_activity_builder set_party","url":"shimmer/builders/presence_activity_builder.html#set_party"},{"doc":"shimmer/builders/presence_activity_builder","title":"set_secrets","content":"pub fn set_secrets(self: PresenceActivityBuilder, secrets: PresenceActivitySecrets) -&gt; PresenceActivityBuilder\n\nSynonyms:\nshimmer/builders/presence_activity_builder.set_secrets\nshimmer/builders/presence_activity_builder set_secrets","url":"shimmer/builders/presence_activity_builder.html#set_secrets"},{"doc":"shimmer/builders/presence_activity_builder","title":"set_state","content":"pub fn set_state(self: PresenceActivityBuilder, state: String) -&gt; PresenceActivityBuilder\n\nSynonyms:\nshimmer/builders/presence_activity_builder.set_state\nshimmer/builders/presence_activity_builder set_state","url":"shimmer/builders/presence_activity_builder.html#set_state"},{"doc":"shimmer/builders/presence_activity_builder","title":"set_timestamps","content":"pub fn set_timestamps(self: PresenceActivityBuilder, timestamps: PresenceActivityTimestamps) -&gt; PresenceActivityBuilder\n\nSynonyms:\nshimmer/builders/presence_activity_builder.set_timestamps\nshimmer/builders/presence_activity_builder set_timestamps","url":"shimmer/builders/presence_activity_builder.html#set_timestamps"},{"doc":"shimmer/builders/presence_activity_builder","title":"set_type","content":"pub fn set_type(self: PresenceActivityBuilder, type_: PresenceActivityType) -&gt; PresenceActivityBuilder\n\nSynonyms:\nshimmer/builders/presence_activity_builder.set_type\nshimmer/builders/presence_activity_builder set_type","url":"shimmer/builders/presence_activity_builder.html#set_type"},{"doc":"shimmer/builders/presence_activity_builder","title":"set_url","content":"pub fn set_url(self: PresenceActivityBuilder, url: String) -&gt; PresenceActivityBuilder\n\nSynonyms:\nshimmer/builders/presence_activity_builder.set_url\nshimmer/builders/presence_activity_builder set_url","url":"shimmer/builders/presence_activity_builder.html#set_url"},{"doc":"shimmer/builders/presence_activity_builder","title":"shimmer/builders/presence_activity_builder","content":"","url":"shimmer/builders/presence_activity_builder.html"},{"doc":"shimmer/builders/presence_builder","title":"PresenceBuilder","content":"pub type PresenceBuilder {\n  PresenceBuilder(\n    status: Option(PresenceStatus),\n    activities: List(PresenceActivity),\n    afk: Option(Bool),\n    since: Option(Int),\n  )\n}\n\nPresenceBuilder(\n  status: Option(PresenceStatus),\n  activities: List(PresenceActivity),\n  afk: Option(Bool),\n  since: Option(Int),\n)\n\n\nSynonyms:\nshimmer/builders/presence_builder.PresenceBuilder\nshimmer/builders/presence_builder PresenceBuilder","url":"shimmer/builders/presence_builder.html#PresenceBuilder"},{"doc":"shimmer/builders/presence_builder","title":"add_activity","content":"pub fn add_activity(self: PresenceBuilder, activity: PresenceActivity) -&gt; PresenceBuilder\n\nSynonyms:\nshimmer/builders/presence_builder.add_activity\nshimmer/builders/presence_builder add_activity","url":"shimmer/builders/presence_builder.html#add_activity"},{"doc":"shimmer/builders/presence_builder","title":"add_activity_from_builder","content":"pub fn add_activity_from_builder(self: PresenceBuilder, activity_builder: PresenceActivityBuilder) -&gt; Result(\n  PresenceBuilder,\n  ShimmerError,\n)\n\nSynonyms:\nshimmer/builders/presence_builder.add_activity_from_builder\nshimmer/builders/presence_builder add_activity_from_builder","url":"shimmer/builders/presence_builder.html#add_activity_from_builder"},{"doc":"shimmer/builders/presence_builder","title":"build","content":"pub fn build(self: PresenceBuilder) -&gt; Result(\n  Presence,\n  ShimmerError,\n)\n\nSynonyms:\nshimmer/builders/presence_builder.build\nshimmer/builders/presence_builder build","url":"shimmer/builders/presence_builder.html#build"},{"doc":"shimmer/builders/presence_builder","title":"new","content":"pub fn new() -&gt; PresenceBuilder\n\nSynonyms:\nshimmer/builders/presence_builder.new\nshimmer/builders/presence_builder new","url":"shimmer/builders/presence_builder.html#new"},{"doc":"shimmer/builders/presence_builder","title":"set_activities","content":"pub fn set_activities(self: PresenceBuilder, activities: List(\n    PresenceActivity,\n  )) -&gt; PresenceBuilder\n\nSynonyms:\nshimmer/builders/presence_builder.set_activities\nshimmer/builders/presence_builder set_activities","url":"shimmer/builders/presence_builder.html#set_activities"},{"doc":"shimmer/builders/presence_builder","title":"set_afk","content":"pub fn set_afk(self: PresenceBuilder, afk: Bool) -&gt; PresenceBuilder\n\nSynonyms:\nshimmer/builders/presence_builder.set_afk\nshimmer/builders/presence_builder set_afk","url":"shimmer/builders/presence_builder.html#set_afk"},{"doc":"shimmer/builders/presence_builder","title":"set_since","content":"pub fn set_since(self: PresenceBuilder, since: Int) -&gt; PresenceBuilder\n\nSynonyms:\nshimmer/builders/presence_builder.set_since\nshimmer/builders/presence_builder set_since","url":"shimmer/builders/presence_builder.html#set_since"},{"doc":"shimmer/builders/presence_builder","title":"set_status","content":"pub fn set_status(self: PresenceBuilder, status: PresenceStatus) -&gt; PresenceBuilder\n\nSynonyms:\nshimmer/builders/presence_builder.set_status\nshimmer/builders/presence_builder set_status","url":"shimmer/builders/presence_builder.html#set_status"},{"doc":"shimmer/builders/presence_builder","title":"shimmer/builders/presence_builder","content":"","url":"shimmer/builders/presence_builder.html"},{"doc":"shimmer/internal/network/gun","title":"ConnectionPid","content":"pub external type ConnectionPid\n\n\nSynonyms:\nshimmer/internal/network/gun.ConnectionPid\nshimmer/internal/network/gun ConnectionPid","url":"shimmer/internal/network/gun.html#ConnectionPid"},{"doc":"shimmer/internal/network/gun","title":"Frame","content":"pub type Frame {\n  Close\n  Text(String)\n  Binary(BitString)\n}\n\nClose\n\n\nText(String)\n\n\nBinary(BitString)\n\n\nSynonyms:\nshimmer/internal/network/gun.Frame\nshimmer/internal/network/gun Frame","url":"shimmer/internal/network/gun.html#Frame"},{"doc":"shimmer/internal/network/gun","title":"StreamReference","content":"pub external type StreamReference\n\n\nSynonyms:\nshimmer/internal/network/gun.StreamReference\nshimmer/internal/network/gun StreamReference","url":"shimmer/internal/network/gun.html#StreamReference"},{"doc":"shimmer/internal/network/gun","title":"await_up","content":"pub external fn await_up(\n  ConnectionPid,\n) -&gt; Result(Dynamic, Dynamic)\n\nSynonyms:\nshimmer/internal/network/gun.await_up\nshimmer/internal/network/gun await_up","url":"shimmer/internal/network/gun.html#await_up"},{"doc":"shimmer/internal/network/gun","title":"open","content":"pub fn open(host: String, port: Int) -&gt; Result(\n  ConnectionPid,\n  Dynamic,\n)\n\nSynonyms:\nshimmer/internal/network/gun.open\nshimmer/internal/network/gun open","url":"shimmer/internal/network/gun.html#open"},{"doc":"shimmer/internal/network/gun","title":"open_erl","content":"pub external fn open_erl(\n  Charlist,\n  Int,\n) -&gt; Result(ConnectionPid, Dynamic)\n\nSynonyms:\nshimmer/internal/network/gun.open_erl\nshimmer/internal/network/gun open_erl","url":"shimmer/internal/network/gun.html#open_erl"},{"doc":"shimmer/internal/network/gun","title":"ws_send","content":"pub fn ws_send(pid: ConnectionPid, frame: Frame) -&gt; Nil\n\nSynonyms:\nshimmer/internal/network/gun.ws_send\nshimmer/internal/network/gun ws_send","url":"shimmer/internal/network/gun.html#ws_send"},{"doc":"shimmer/internal/network/gun","title":"ws_upgrade","content":"pub external fn ws_upgrade(\n  ConnectionPid,\n  String,\n  List(Header),\n) -&gt; StreamReference\n\nSynonyms:\nshimmer/internal/network/gun.ws_upgrade\nshimmer/internal/network/gun ws_upgrade","url":"shimmer/internal/network/gun.html#ws_upgrade"},{"doc":"shimmer/internal/network/gun","title":"shimmer/internal/network/gun","content":" Based upon github.com/lpil/nerf","url":"shimmer/internal/network/gun.html"},{"doc":"shimmer/internal/network/websocket","title":"ConnectError","content":"pub type ConnectError {\n  ConnectionRefused(status: Int, headers: List(Header))\n  ConnectionFailed(reason: Dynamic)\n}\n The URI of the websocket server to connect to\nConnectionRefused(status: Int, headers: List(Header))\n\n\nConnectionFailed(reason: Dynamic)\n\n\nSynonyms:\nshimmer/internal/network/websocket.ConnectError\nshimmer/internal/network/websocket ConnectError","url":"shimmer/internal/network/websocket.html#ConnectError"},{"doc":"shimmer/internal/network/websocket","title":"Connection","content":"pub opaque type Connection\n\n\nSynonyms:\nshimmer/internal/network/websocket.Connection\nshimmer/internal/network/websocket Connection","url":"shimmer/internal/network/websocket.html#Connection"},{"doc":"shimmer/internal/network/websocket","title":"Frame","content":"pub type Frame {\n  Close(Int, String)\n  Text(String)\n  Binary(BitString)\n}\n\nClose(Int, String)\n\n\nText(String)\n\n\nBinary(BitString)\n\n\nSynonyms:\nshimmer/internal/network/websocket.Frame\nshimmer/internal/network/websocket Frame","url":"shimmer/internal/network/websocket.html#Frame"},{"doc":"shimmer/internal/network/websocket","title":"close","content":"pub fn close(conn: Connection) -&gt; Nil\n\nSynonyms:\nshimmer/internal/network/websocket.close\nshimmer/internal/network/websocket close","url":"shimmer/internal/network/websocket.html#close"},{"doc":"shimmer/internal/network/websocket","title":"connect","content":"pub fn connect(hostname: String, path: String, on port: Int, with headers: List(\n    #(String, String),\n  )) -&gt; Result(Connection, ConnectError)\n\nSynonyms:\nshimmer/internal/network/websocket.connect\nshimmer/internal/network/websocket connect","url":"shimmer/internal/network/websocket.html#connect"},{"doc":"shimmer/internal/network/websocket","title":"receive","content":"pub external fn receive(\n  from: Connection,\n  within: Int,\n) -&gt; Result(Frame, Nil)\n\nSynonyms:\nshimmer/internal/network/websocket.receive\nshimmer/internal/network/websocket receive","url":"shimmer/internal/network/websocket.html#receive"},{"doc":"shimmer/internal/network/websocket","title":"send","content":"pub fn send(to conn: Connection, this message: BitString) -&gt; Nil\n\nSynonyms:\nshimmer/internal/network/websocket.send\nshimmer/internal/network/websocket send","url":"shimmer/internal/network/websocket.html#send"},{"doc":"shimmer/internal/network/websocket","title":"shimmer/internal/network/websocket","content":" Based upon github.com/lpil/nerf","url":"shimmer/internal/network/websocket.html"},{"doc":"shimmer/intents","title":"Intent","content":"pub type Intent {\n  Guilds\n  GuildMembers\n  GuildBans\n  GuildEmojisAndStickers\n  GuildIntegrations\n  GuildWebhooks\n  GuildInvites\n  GuildVoiceStates\n  GuildPresences\n  GuildMessages\n  GuildMessageReactions\n  GuildMessageTyping\n  DirectMessages\n  DirectMessageReactions\n  DirectMessageTyping\n  MessageContent\n  GuildScheduledEvents\n  GuildAutoModeration\n  GuildAutoModerationExecution\n}\n Enum for easy creation of discord intents for bots\nGuilds\n ## Events:\n - GUILD_CREATE (`on_guild_create`)\n - GUILD_UPDATE (`on_guild_update`)\n - GUILD_DELETE (`on_guild_delete`)\n - GUILD_ROLE_CREATE (`on_guild_role_create`)\n - GUILD_ROLE_UPDATE (`on_guild_role_update`)\n - GUILD_ROLE_DELETE (`on_guild_role_delete`)\n - CHANNEL_CREATE (`on_channel_create`)\n - CHANNEL_UPDATE (`on_channel_update`)\n - CHANNEL_DELETE (`on_channel_delete`)\n - CHANNEL_PINS_UPDATE (`on_channel_pins_update`)\n - THREAD_CREATE (`on_thread_create`)\n - THREAD_UPDATE (`on_thread_update`)\n - THREAD_DELETE (`on_thread_delete`)\n - THREAD_LIST_SYNC (`on_thread_list_sync`)\n - THREAD_MEMBER_UPDATE (`on_thread_member_update`)\n - THREAD_MEMBERS_UPDATE (`on_thread_members_update`)\n - STAGE_INSTANCE_CREATE (`on_stage_instance_create`)\n - STAGE_INSTANCE_UPDATE (`on_stage_instance_update`)\n - STAGE_INSTANCE_DELETE (`on_stage_instance_delete`)\n ## Intents:\n Represented as 1 &lt;&lt; 0\n\nGuildMembers\n ## Events:\n - GUILD_MEMBER_ADD (`on_guild_member_add`)\n - GUILD_MEMBER_UPDATE (`on_guild_member_update`)\n - GUILD_MEMBER_REMOVE (`on_guild_member_remove`)\n - THREAD_MEMBERS_UPDATE (`on_thread_members_update`)\n ## Intents:\n Represented as 1 &lt;&lt; 1\n\nGuildBans\n ## Events:\n - GUILD_BAN_ADD (`on_guild_ban_add`)\n - GUILD_BAN_REMOVE (`on_guild_ban_remove`)\n ## Intents:\n Represented as 1 &lt;&lt; 2\n\nGuildEmojisAndStickers\n ## Events:\n - GUILD_EMOJIS_UPDATE (`on_guild_emojis_update`)\n - GUILD_STICKERS_UPDATE (`on_guild_stickers_update`)\n ## Intents:\n Represented as 1 &lt;&lt; 3\n\nGuildIntegrations\n ## Events:\n - GUILD_INTEGRATIONS_UPDATE (`on_guild_integrations_update`)\n - INTEGRATION_CREATE (`on_integration_create`)\n - INTEGRATION_UPDATE (`on_integration_update`)\n - INTEGRATION_DELETE (`on_integration_delete`)\n ## Intents:\n Represented as 1 &lt;&lt; 4\n\nGuildWebhooks\n ## Events:\n - WEBHOOKS_UPDATE (`on_webhooks_update`)\n ## Intents:\n Represented as 1 &lt;&lt; 5\n\nGuildInvites\n ## Events:\n - INVITE_CREATE (`on_invite_create`)\n - INVITE_DELETE (`on_invite_delete`)\n ## Intents:\n Represented as 1 &lt;&lt; 6\n\nGuildVoiceStates\n ## Events:\n - VOICE_STATE_UPDATE (`on_voice_state_update`)\n ## Intents:\n Represented as 1 &lt;&lt; 7\n\nGuildPresences\n ## Events:\n - PRESENCE_UPDATE (`on_presence_update`)\n ## Intents:\n Represented as 1 &lt;&lt; 8\n\nGuildMessages\n ## Events:\n - MESSAGE_CREATE (`on_message_create`)\n - MESSAGE_UPDATE (`on_message_update`)\n - MESSAGE_DELETE (`on_message_delete`)\n - MESSAGE_DELETE_BULK (`on_message_delete_bulk`)\n ## Intents:\n Represented as 1 &lt;&lt; 9\n\nGuildMessageReactions\n ## Events:\n - MESSAGE_REACTION_ADD (`on_message_reaction_add`)\n - MESSAGE_REACTION_REMOVE (`on_message_reaction_remove`)\n - MESSAGE_REACTION_REMOVE_ALL (`on_message_reaction_remove_all`)\n - MESSAGE_REACTION_REMOVE_EMOJI (`on_message_reaction_remove_emoji`)\n ## Intents:\n Represented as 1 &lt;&lt; 10\n\nGuildMessageTyping\n ## Events:\n - TYPING_START (`on_typing_start`)\n ## Intents:\n Represented as 1 &lt;&lt; 11\n\nDirectMessages\n ## Events:\n - MESSAGE_CREATE (`on_message_created`)\n - MESSAGE_UPDATE (`on_message_updated`)\n - MESSAGE_DELETE (`on_message_deleted`)\n - CHANNEL_PINS_UPDATE (`on_channel_pins_update`)\n ## Intents:\n Represented as 1 &lt;&lt; 12\n\nDirectMessageReactions\n ## Events:\n - MESSAGE_REACTION_ADD (`on_message_reaction_add`)\n - MESSAGE_REACTION_REMOVE (`on_message_reaction_remove`)\n - MESSAGE_REACTION_REMOVE_ALL (`on_message_reaction_remove_all`)\n - MESSAGE_REACTION_REMOVE_EMOJI (`on_message_reaction_remove_emoji`)\n ## Intents:\n Represented as 1 &lt;&lt; 13\n\nDirectMessageTyping\n ## Events:\n - TYPING_START (`on_typing_start`)\n ## Intents:\n Represented as 1 &lt;&lt; 14\n\nMessageContent\n Allows access to the content of messages, used with the `DirectMessages` and `GuildMessages` intents.\n ## Intents:\n Represented as 1 &lt;&lt; 15\n\nGuildScheduledEvents\n ## Events:\n - GUILD_SCHEDULED_EVENT_CREATE (`on_guild_scheduled_event_create`)\n - GUILD_SCHEDULED_EVENT_UPDATE (`on_guild_scheduled_event_update`)\n - GUILD_SCHEDULED_EVENT_DELETE (`on_guild_scheduled_event_delete`)\n - GUILD_SCHEDULED_EVENT_USER_ADD (`on_guild_scheduled_event_user_add`)\n - GUILD_SCHEDULED_EVENT_USER_REMOVE (`on_guild_scheduled_event_user_remove`)\n ## Intents:\n Represented as 1 &lt;&lt; 16\n\nGuildAutoModeration\n ## Events:\n - AUTO_MODERATION_RULE_CREATE (`on_auto_moderation_rule_create`)\n - AUTO_MODERATION_RULE_UPDATE (`on_auto_moderation_rule_update`)\n - AUTO_MODERATION_RULE_DELETE (`on_auto_moderation_rule_delete`)\n ## Intents:\n Represented as 1 &lt;&lt; 20\n\nGuildAutoModerationExecution\n ## Events:\n - AUTO_MODERATION_ACTION_EXECUTION (`on_auto_moderation_action_execution`)\n ## Intents:\n Represented as 1 &lt;&lt; 21\n\nSynonyms:\nshimmer/intents.Intent\nshimmer/intents Intent","url":"shimmer/intents.html#Intent"},{"doc":"shimmer/intents","title":"all","content":"pub fn all() -&gt; List(Intent)\n All intents\nSynonyms:\nshimmer/intents.all\nshimmer/intents all","url":"shimmer/intents.html#all"},{"doc":"shimmer/intents","title":"default","content":"pub fn default() -&gt; List(Intent)\n The default intents enabled, limited to recieved the least data required\n ## Intents:\n - Guilds\nSynonyms:\nshimmer/intents.default\nshimmer/intents default","url":"shimmer/intents.html#default"},{"doc":"shimmer/intents","title":"intent_to_int","content":"pub fn intent_to_int(intent: Intent) -&gt; Int\n\nSynonyms:\nshimmer/intents.intent_to_int\nshimmer/intents intent_to_int","url":"shimmer/intents.html#intent_to_int"},{"doc":"shimmer/intents","title":"intents_to_int","content":"pub fn intents_to_int(intents: List(Intent)) -&gt; Int\n\nSynonyms:\nshimmer/intents.intents_to_int\nshimmer/intents intents_to_int","url":"shimmer/intents.html#intents_to_int"},{"doc":"shimmer/intents","title":"unprivileged","content":"pub fn unprivileged() -&gt; List(Intent)\n All intents except for `GuildPresences` `GuildMembers` `MessageContent`\nSynonyms:\nshimmer/intents.unprivileged\nshimmer/intents unprivileged","url":"shimmer/intents.html#unprivileged"},{"doc":"shimmer/intents","title":"shimmer/intents","content":"","url":"shimmer/intents.html"},{"doc":"shimmer/client","title":"Client","content":"pub type Client(message) {\n  Client(\n    token: String,\n    intents: List(Intent),\n    to_self: Subject(message),\n    shard: Shard(message),\n  )\n}\n\nClient(\n  token: String,\n  intents: List(Intent),\n  to_self: Subject(message),\n  shard: Shard(message),\n)\n\n\nSynonyms:\nshimmer/client.Client\nshimmer/client Client","url":"shimmer/client.html#Client"},{"doc":"shimmer/client","title":"Shard","content":"pub type Shard(message) {\n  Shard(id: Int, total: Int, to_all: Subject(message))\n}\n\nShard(id: Int, total: Int, to_all: Subject(message))\n\n\nSynonyms:\nshimmer/client.Shard\nshimmer/client Shard","url":"shimmer/client.html#Shard"},{"doc":"shimmer/client","title":"shimmer/client","content":"","url":"shimmer/client.html"},{"doc":"shimmer/internal/erl/uri","title":"UriMap","content":"pub type UriMap {\n  UriMap(\n    host: String,\n    scheme: String,\n    path: String,\n    query: String,\n  )\n}\n\nUriMap(host: String, scheme: String, path: String, query: String)\n\n\nSynonyms:\nshimmer/internal/erl/uri.UriMap\nshimmer/internal/erl/uri UriMap","url":"shimmer/internal/erl/uri.html#UriMap"},{"doc":"shimmer/internal/erl/uri","title":"parse","content":"pub external fn parse(uri: String) -&gt; UriMap\n\nSynonyms:\nshimmer/internal/erl/uri.parse\nshimmer/internal/erl/uri parse","url":"shimmer/internal/erl/uri.html#parse"},{"doc":"shimmer/internal/erl/uri","title":"shimmer/internal/erl/uri","content":"","url":"shimmer/internal/erl/uri.html"},{"doc":"shimmer/internal/map_helpers","title":"dyn_atom","content":"pub fn dyn_atom(val: String) -&gt; Dynamic\n\nSynonyms:\nshimmer/internal/map_helpers.dyn_atom\nshimmer/internal/map_helpers dyn_atom","url":"shimmer/internal/map_helpers.html#dyn_atom"},{"doc":"shimmer/internal/map_helpers","title":"dyn_key","content":"pub fn dyn_key(val: String) -&gt; Dynamic\n\nSynonyms:\nshimmer/internal/map_helpers.dyn_key\nshimmer/internal/map_helpers dyn_key","url":"shimmer/internal/map_helpers.html#dyn_key"},{"doc":"shimmer/internal/map_helpers","title":"get_field_safe","content":"pub fn get_field_safe(map: Map(a, Dynamic), key: a, decoder: fn(\n    Dynamic,\n  ) -&gt; Result(b, List(DecodeError))) -&gt; Result(b, ShimmerError)\n\nSynonyms:\nshimmer/internal/map_helpers.get_field_safe\nshimmer/internal/map_helpers get_field_safe","url":"shimmer/internal/map_helpers.html#get_field_safe"},{"doc":"shimmer/internal/map_helpers","title":"get_map_field_safe","content":"pub fn get_map_field_safe(map: Map(a, Dynamic), key: a) -&gt; Result(\n  Map(Dynamic, Dynamic),\n  ShimmerError,\n)\n\nSynonyms:\nshimmer/internal/map_helpers.get_map_field_safe\nshimmer/internal/map_helpers get_map_field_safe","url":"shimmer/internal/map_helpers.html#get_map_field_safe"},{"doc":"shimmer/internal/map_helpers","title":"shimmer/internal/map_helpers","content":"","url":"shimmer/internal/map_helpers.html"},{"doc":"shimmer/ws/packet","title":"from_dynamic","content":"pub fn from_dynamic(encoded: Dynamic) -&gt; Result(\n  #(\n    Int,\n    Option(Int),\n    Option(String),\n    Option(Map(Dynamic, Dynamic)),\n  ),\n  ShimmerError,\n)\n\nSynonyms:\nshimmer/ws/packet.from_dynamic\nshimmer/ws/packet from_dynamic","url":"shimmer/ws/packet.html#from_dynamic"},{"doc":"shimmer/ws/packet","title":"shimmer/ws/packet","content":"","url":"shimmer/ws/packet.html"},{"doc":"shimmer/ws/packets/hello","title":"HelloPacketData","content":"pub type HelloPacketData {\n  HelloPacketData(heartbeat_interval: Int)\n}\n\nHelloPacketData(heartbeat_interval: Int)\n\n\nSynonyms:\nshimmer/ws/packets/hello.HelloPacketData\nshimmer/ws/packets/hello HelloPacketData","url":"shimmer/ws/packets/hello.html#HelloPacketData"},{"doc":"shimmer/ws/packets/hello","title":"from_map","content":"pub fn from_map(map: Map(Dynamic, Dynamic)) -&gt; Result(\n  HelloPacketData,\n  ShimmerError,\n)\n\nSynonyms:\nshimmer/ws/packets/hello.from_map\nshimmer/ws/packets/hello from_map","url":"shimmer/ws/packets/hello.html#from_map"},{"doc":"shimmer/ws/packets/hello","title":"shimmer/ws/packets/hello","content":"","url":"shimmer/ws/packets/hello.html"},{"doc":"shimmer/types/user","title":"User","content":"pub type User {\n  PartialUser(\n    id: Snowflake,\n    username: String,\n    discriminator: String,\n    avatar: Option(String),\n  )\n  FullUser(\n    id: Snowflake,\n    username: String,\n    discriminator: String,\n    avatar: Option(String),\n    bot: Bool,\n    system: Bool,\n    mfa_enabled: Bool,\n    banner: Option(String),\n    accent_color: Option(Int),\n    verified: Bool,\n    email: Option(String),\n    flags: Int,\n    premium_type: Int,\n    public_flags: Int,\n  )\n}\n\nPartialUser(\n  id: Snowflake,\n  username: String,\n  discriminator: String,\n  avatar: Option(String),\n)\n\n\nFullUser(\n  id: Snowflake,\n  username: String,\n  discriminator: String,\n  avatar: Option(String),\n  bot: Bool,\n  system: Bool,\n  mfa_enabled: Bool,\n  banner: Option(String),\n  accent_color: Option(Int),\n  verified: Bool,\n  email: Option(String),\n  flags: Int,\n  premium_type: Int,\n  public_flags: Int,\n)\n\n\nSynonyms:\nshimmer/types/user.User\nshimmer/types/user User","url":"shimmer/types/user.html#User"},{"doc":"shimmer/types/user","title":"from_json_string","content":"pub fn from_json_string(encoded: String) -&gt; Result(\n  User,\n  ShimmerError,\n)\n\nSynonyms:\nshimmer/types/user.from_json_string\nshimmer/types/user from_json_string","url":"shimmer/types/user.html#from_json_string"},{"doc":"shimmer/types/user","title":"from_map","content":"pub fn from_map(map: Map(Dynamic, Dynamic), key_func: fn(String) -&gt;\n    Dynamic) -&gt; Result(User, ShimmerError)\n\nSynonyms:\nshimmer/types/user.from_map\nshimmer/types/user from_map","url":"shimmer/types/user.html#from_map"},{"doc":"shimmer/types/user","title":"shimmer/types/user","content":"","url":"shimmer/types/user.html"},{"doc":"shimmer/ws/packets/ready","title":"ReadyPacket","content":"pub type ReadyPacket {\n  ReadyPacket(\n    user: User,\n    session_id: String,\n    resume_gateway_url: String,\n  )\n}\n\nReadyPacket(\n  user: User,\n  session_id: String,\n  resume_gateway_url: String,\n)\n\n\nSynonyms:\nshimmer/ws/packets/ready.ReadyPacket\nshimmer/ws/packets/ready ReadyPacket","url":"shimmer/ws/packets/ready.html#ReadyPacket"},{"doc":"shimmer/ws/packets/ready","title":"from_map","content":"pub fn from_map(map: Map(Dynamic, Dynamic)) -&gt; Result(\n  ReadyPacket,\n  ShimmerError,\n)\n\nSynonyms:\nshimmer/ws/packets/ready.from_map\nshimmer/ws/packets/ready from_map","url":"shimmer/ws/packets/ready.html#from_map"},{"doc":"shimmer/ws/packets/ready","title":"shimmer/ws/packets/ready","content":"","url":"shimmer/ws/packets/ready.html"},{"doc":"shimmer/ws/packets/identify","title":"IdentifyPacketData","content":"pub type IdentifyPacketData {\n  IdentifyPacketData(\n    token: String,\n    intents: Int,\n    shard_id: Int,\n    total_shards: Int,\n  )\n}\n\nIdentifyPacketData(\n  token: String,\n  intents: Int,\n  shard_id: Int,\n  total_shards: Int,\n)\n\n\nSynonyms:\nshimmer/ws/packets/identify.IdentifyPacketData\nshimmer/ws/packets/identify IdentifyPacketData","url":"shimmer/ws/packets/identify.html#IdentifyPacketData"},{"doc":"shimmer/ws/packets/identify","title":"to_etf","content":"pub fn to_etf(data: IdentifyPacketData) -&gt; BitString\n\nSynonyms:\nshimmer/ws/packets/identify.to_etf\nshimmer/ws/packets/identify to_etf","url":"shimmer/ws/packets/identify.html#to_etf"},{"doc":"shimmer/ws/packets/identify","title":"shimmer/ws/packets/identify","content":"","url":"shimmer/ws/packets/identify.html"},{"doc":"shimmer/types/message","title":"Message","content":"pub type Message {\n  Message(\n    id: Snowflake,\n    channel_id: Snowflake,\n    author: User,\n    content: Option(String),\n    timestamp: String,\n  )\n}\n\nMessage(\n  id: Snowflake,\n  channel_id: Snowflake,\n  author: User,\n  content: Option(String),\n  timestamp: String,\n)\n\n\nSynonyms:\nshimmer/types/message.Message\nshimmer/types/message Message","url":"shimmer/types/message.html#Message"},{"doc":"shimmer/types/message","title":"from_map","content":"pub fn from_map(map: Map(Dynamic, Dynamic)) -&gt; Result(\n  Message,\n  ShimmerError,\n)\n\nSynonyms:\nshimmer/types/message.from_map\nshimmer/types/message from_map","url":"shimmer/types/message.html#from_map"},{"doc":"shimmer/types/message","title":"shimmer/types/message","content":"","url":"shimmer/types/message.html"},{"doc":"shimmer/types/member","title":"Member","content":"pub type Member {\n  Member\n  PartialMember\n}\n\nMember\n\n\nPartialMember\n\n\nSynonyms:\nshimmer/types/member.Member\nshimmer/types/member Member","url":"shimmer/types/member.html#Member"},{"doc":"shimmer/types/member","title":"shimmer/types/member","content":"","url":"shimmer/types/member.html"},{"doc":"shimmer/ws/packets/message_create","title":"MessageCreate","content":"pub type MessageCreate {\n  MessageCreate(\n    message: Message,\n    guild_id: Option(Snowflake),\n    member: Option(Member),\n    mentions: List(User),\n  )\n}\n\nMessageCreate(\n  message: Message,\n  guild_id: Option(Snowflake),\n  member: Option(Member),\n  mentions: List(User),\n)\n\n\nSynonyms:\nshimmer/ws/packets/message_create.MessageCreate\nshimmer/ws/packets/message_create MessageCreate","url":"shimmer/ws/packets/message_create.html#MessageCreate"},{"doc":"shimmer/ws/packets/message_create","title":"from_map","content":"pub fn from_map(map: Map(Dynamic, Dynamic)) -&gt; Result(\n  MessageCreate,\n  ShimmerError,\n)\n\nSynonyms:\nshimmer/ws/packets/message_create.from_map\nshimmer/ws/packets/message_create from_map","url":"shimmer/ws/packets/message_create.html#from_map"},{"doc":"shimmer/ws/packets/message_create","title":"shimmer/ws/packets/message_create","content":"","url":"shimmer/ws/packets/message_create.html"},{"doc":"shimmer/handlers","title":"Handlers","content":"pub type Handlers(message) {\n  Handlers(\n    on_ready: fn(ReadyPacket, Client(message)) -&gt; Nil,\n    on_message: fn(MessageCreate, Client(message)) -&gt; Nil,\n    on_heartbeat_ack: fn(Client(message)) -&gt; Nil,\n    on_disconnect: fn(Int, Client(message)) -&gt; Nil,\n  )\n}\n\nHandlers(\n  on_ready: fn(ReadyPacket, Client(message)) -&gt; Nil,\n  on_message: fn(MessageCreate, Client(message)) -&gt; Nil,\n  on_heartbeat_ack: fn(Client(message)) -&gt; Nil,\n  on_disconnect: fn(Int, Client(message)) -&gt; Nil,\n)\n\n\nSynonyms:\nshimmer/handlers.Handlers\nshimmer/handlers Handlers","url":"shimmer/handlers.html#Handlers"},{"doc":"shimmer/handlers","title":"HandlersBuilder","content":"pub type HandlersBuilder(message) {\n  HandlersBuilder(\n    on_ready: Option(fn(ReadyPacket, Client(message)) -&gt; Nil),\n    on_message: Option(fn(MessageCreate, Client(message)) -&gt; Nil),\n    on_heartbeat_ack: Option(fn(Client(message)) -&gt; Nil),\n    on_disconnect: Option(fn(Int, Client(message)) -&gt; Nil),\n  )\n}\n\nHandlersBuilder(\n  on_ready: Option(fn(ReadyPacket, Client(message)) -&gt; Nil),\n  on_message: Option(fn(MessageCreate, Client(message)) -&gt; Nil),\n  on_heartbeat_ack: Option(fn(Client(message)) -&gt; Nil),\n  on_disconnect: Option(fn(Int, Client(message)) -&gt; Nil),\n)\n\non_ready\n&lt;p&gt;When the bot is online and ready.&lt;/p&gt;\n\non_message\n&lt;p&gt;When a new message is recieved.&lt;/p&gt;\n\non_heartbeat_ack\n&lt;p&gt;Send when the internal heartbeats are acknowlaged by the gateway.&lt;/p&gt;\n\non_disconnect\n&lt;p&gt;Called when the gateway connection is closed for any reason. The function is given the close code we recieved from discord.&lt;/p&gt;\n\nSynonyms:\nshimmer/handlers.HandlersBuilder\nshimmer/handlers HandlersBuilder","url":"shimmer/handlers.html#HandlersBuilder"},{"doc":"shimmer/handlers","title":"handlers_from_builder","content":"pub fn handlers_from_builder(builder: HandlersBuilder(a)) -&gt; Handlers(\n  a,\n)\n\nSynonyms:\nshimmer/handlers.handlers_from_builder\nshimmer/handlers handlers_from_builder","url":"shimmer/handlers.html#handlers_from_builder"},{"doc":"shimmer/handlers","title":"new_builder","content":"pub fn new_builder() -&gt; HandlersBuilder(a)\n\nSynonyms:\nshimmer/handlers.new_builder\nshimmer/handlers new_builder","url":"shimmer/handlers.html#new_builder"},{"doc":"shimmer/handlers","title":"on_disconnect","content":"pub fn on_disconnect(builder: HandlersBuilder(a), f: fn(\n    Int,\n    Client(a),\n  ) -&gt; Nil) -&gt; HandlersBuilder(a)\n\nSynonyms:\nshimmer/handlers.on_disconnect\nshimmer/handlers on_disconnect","url":"shimmer/handlers.html#on_disconnect"},{"doc":"shimmer/handlers","title":"on_heartbeat_ack","content":"pub fn on_heartbeat_ack(builder: HandlersBuilder(a), f: fn(\n    Client(a),\n  ) -&gt; Nil) -&gt; HandlersBuilder(a)\n\nSynonyms:\nshimmer/handlers.on_heartbeat_ack\nshimmer/handlers on_heartbeat_ack","url":"shimmer/handlers.html#on_heartbeat_ack"},{"doc":"shimmer/handlers","title":"on_message","content":"pub fn on_message(builder: HandlersBuilder(a), f: fn(\n    MessageCreate,\n    Client(a),\n  ) -&gt; Nil) -&gt; HandlersBuilder(a)\n\nSynonyms:\nshimmer/handlers.on_message\nshimmer/handlers on_message","url":"shimmer/handlers.html#on_message"},{"doc":"shimmer/handlers","title":"on_ready","content":"pub fn on_ready(builder: HandlersBuilder(a), f: fn(\n    ReadyPacket,\n    Client(a),\n  ) -&gt; Nil) -&gt; HandlersBuilder(a)\n\nSynonyms:\nshimmer/handlers.on_ready\nshimmer/handlers on_ready","url":"shimmer/handlers.html#on_ready"},{"doc":"shimmer/handlers","title":"shimmer/handlers","content":"","url":"shimmer/handlers.html"},{"doc":"shimmer/ws/event_loop","title":"ActorState","content":"pub type ActorState {\n  ActorState(\n    heartbeat_interval: Int,\n    sequence: Int,\n    conn: Connection,\n    meta: WebsocketMeta,\n    selector: Selector(Message),\n    subject: Subject(Message),\n    shard: Shard(Message),\n    session: Option(GatewaySession),\n  )\n}\n\nActorState(\n  heartbeat_interval: Int,\n  sequence: Int,\n  conn: Connection,\n  meta: WebsocketMeta,\n  selector: Selector(Message),\n  subject: Subject(Message),\n  shard: Shard(Message),\n  session: Option(GatewaySession),\n)\n\n\nSynonyms:\nshimmer/ws/event_loop.ActorState\nshimmer/ws/event_loop ActorState","url":"shimmer/ws/event_loop.html#ActorState"},{"doc":"shimmer/ws/event_loop","title":"GatewaySession","content":"pub type GatewaySession {\n  GatewaySession(session_id: String, resume_gateway_url: String)\n}\n\nGatewaySession(session_id: String, resume_gateway_url: String)\n\n\nSynonyms:\nshimmer/ws/event_loop.GatewaySession\nshimmer/ws/event_loop GatewaySession","url":"shimmer/ws/event_loop.html#GatewaySession"},{"doc":"shimmer/ws/event_loop","title":"Message","content":"pub type Message {\n  WebsocketFrame(websocket.Frame)\n  UpdatePresence(Presence)\n  Beat\n  Halt\n}\n\nWebsocketFrame(websocket.Frame)\n Frames from Gun\n\nUpdatePresence(Presence)\n Send a request to update the Bot&#39;s presence\n\nBeat\n Heartbeat Message Only\n\nHalt\n Kill the Actor\n\nSynonyms:\nshimmer/ws/event_loop.Message\nshimmer/ws/event_loop Message","url":"shimmer/ws/event_loop.html#Message"},{"doc":"shimmer/ws/event_loop","title":"WebsocketMeta","content":"pub type WebsocketMeta {\n  WebsocketMeta(\n    token: String,\n    intents: List(Intent),\n    handlers: Handlers(Message),\n  )\n}\n\nWebsocketMeta(\n  token: String,\n  intents: List(Intent),\n  handlers: Handlers(Message),\n)\n\n\nSynonyms:\nshimmer/ws/event_loop.WebsocketMeta\nshimmer/ws/event_loop WebsocketMeta","url":"shimmer/ws/event_loop.html#WebsocketMeta"},{"doc":"shimmer/ws/event_loop","title":"actor_loop","content":"pub fn actor_loop(msg: Message, state: ActorState) -&gt; Next(\n  ActorState,\n)\n\nSynonyms:\nshimmer/ws/event_loop.actor_loop\nshimmer/ws/event_loop actor_loop","url":"shimmer/ws/event_loop.html#actor_loop"},{"doc":"shimmer/ws/event_loop","title":"actor_setup","content":"pub fn actor_setup(client: Client(Message), gateway_url: String, handlers: Handlers(\n    Message,\n  )) -&gt; fn() -&gt; InitResult(ActorState, Message)\n\nSynonyms:\nshimmer/ws/event_loop.actor_setup\nshimmer/ws/event_loop actor_setup","url":"shimmer/ws/event_loop.html#actor_setup"},{"doc":"shimmer/ws/event_loop","title":"shimmer/ws/event_loop","content":"","url":"shimmer/ws/event_loop.html"},{"doc":"shimmer/shards","title":"ShardsManager","content":"pub type ShardsManager(message) {\n  ShardsManager(\n    token: String,\n    intents: List(Intent),\n    to_clients: Subject(message),\n    clients: List(Client(message)),\n  )\n}\n\nShardsManager(\n  token: String,\n  intents: List(Intent),\n  to_clients: Subject(message),\n  clients: List(Client(message)),\n)\n\n\nSynonyms:\nshimmer/shards.ShardsManager\nshimmer/shards ShardsManager","url":"shimmer/shards.html#ShardsManager"},{"doc":"shimmer/shards","title":"shimmer/shards","content":"","url":"shimmer/shards.html"},{"doc":"shimmer/http/request","title":"new","content":"pub fn new(method: Method, path: String) -&gt; Request(String)\n\nSynonyms:\nshimmer/http/request.new\nshimmer/http/request new","url":"shimmer/http/request.html#new"},{"doc":"shimmer/http/request","title":"new_with_auth","content":"pub fn new_with_auth(method: Method, path: String, token: String) -&gt; Request(\n  String,\n)\n\nSynonyms:\nshimmer/http/request.new_with_auth\nshimmer/http/request new_with_auth","url":"shimmer/http/request.html#new_with_auth"},{"doc":"shimmer/http/request","title":"set_body","content":"pub fn set_body(request: Request(String), body: String) -&gt; Request(\n  String,\n)\n\nSynonyms:\nshimmer/http/request.set_body\nshimmer/http/request set_body","url":"shimmer/http/request.html#set_body"},{"doc":"shimmer/http/request","title":"shimmer/http/request","content":"","url":"shimmer/http/request.html"},{"doc":"shimmer/internal/types/responses/bot_gateway","title":"BotGatewayResponse","content":"pub type BotGatewayResponse {\n  BotGatewayResponse(url: String, shards: Int)\n}\n\nBotGatewayResponse(url: String, shards: Int)\n\n\nSynonyms:\nshimmer/internal/types/responses/bot_gateway.BotGatewayResponse\nshimmer/internal/types/responses/bot_gateway BotGatewayResponse","url":"shimmer/internal/types/responses/bot_gateway.html#BotGatewayResponse"},{"doc":"shimmer/internal/types/responses/bot_gateway","title":"from_json_string","content":"pub fn from_json_string(encoded: String) -&gt; Result(\n  BotGatewayResponse,\n  ShimmerError,\n)\n\nSynonyms:\nshimmer/internal/types/responses/bot_gateway.from_json_string\nshimmer/internal/types/responses/bot_gateway from_json_string","url":"shimmer/internal/types/responses/bot_gateway.html#from_json_string"},{"doc":"shimmer/internal/types/responses/bot_gateway","title":"shimmer/internal/types/responses/bot_gateway","content":"","url":"shimmer/internal/types/responses/bot_gateway.html"},{"doc":"shimmer/http/endpoints","title":"bot_gateway","content":"pub fn bot_gateway(token: String) -&gt; Result(\n  BotGatewayResponse,\n  ShimmerError,\n)\n\nSynonyms:\nshimmer/http/endpoints.bot_gateway\nshimmer/http/endpoints bot_gateway","url":"shimmer/http/endpoints.html#bot_gateway"},{"doc":"shimmer/http/endpoints","title":"me","content":"pub fn me(token: String) -&gt; Result(User, ShimmerError)\n\nSynonyms:\nshimmer/http/endpoints.me\nshimmer/http/endpoints me","url":"shimmer/http/endpoints.html#me"},{"doc":"shimmer/http/endpoints","title":"send_message","content":"pub fn send_message(token: String, channel_id: String, content: String) -&gt; Result(\n  Bool,\n  ShimmerError,\n)\n\nSynonyms:\nshimmer/http/endpoints.send_message\nshimmer/http/endpoints send_message","url":"shimmer/http/endpoints.html#send_message"},{"doc":"shimmer/http/endpoints","title":"shimmer/http/endpoints","content":"","url":"shimmer/http/endpoints.html"},{"doc":"shimmer","title":"ClientOptions","content":"pub type ClientOptions {\n  ClientOptions(intents: List(Intent))\n}\n\nClientOptions(intents: List(Intent))\n\n\nSynonyms:\nshimmer.ClientOptions\nshimmer ClientOptions","url":"shimmer.html#ClientOptions"},{"doc":"shimmer","title":"connect","content":"pub fn connect(client: Client(Message), handlers_builder: HandlersBuilder(\n    Message,\n  )) -&gt; Result(Client(Message), ShimmerError)\n Opens a websocket connection to the Discord Gateway. Passes this off to an actor to listen to messages.\nSynonyms:\nshimmer.connect\nshimmer connect","url":"shimmer.html#connect"},{"doc":"shimmer","title":"connect_sharded","content":"pub fn connect_sharded(shards: ShardsManager(Message), handlers_builder: HandlersBuilder(\n    Message,\n  )) -&gt; Result(ShardsManager(Message), ShimmerError)\n Opens a sharded websocket connection to the Discord Gateway. Passes this off to an actor to listen to messages.\nSynonyms:\nshimmer.connect_sharded\nshimmer connect_sharded","url":"shimmer.html#connect_sharded"},{"doc":"shimmer","title":"new","content":"pub fn new(token: String) -&gt; Client(Message)\n Create a new client with the defualt setup, reccomended for most users\nSynonyms:\nshimmer.new\nshimmer new","url":"shimmer.html#new"},{"doc":"shimmer","title":"new_sharded","content":"pub fn new_sharded(token: String) -&gt; ShardsManager(Message)\n Create a sharding manager to support larger bots, uses Client under the hood\nSynonyms:\nshimmer.new_sharded\nshimmer new_sharded","url":"shimmer.html#new_sharded"},{"doc":"shimmer","title":"new_sharded_with_opts","content":"pub fn new_sharded_with_opts(token: String, opts: ClientOptions) -&gt; ShardsManager(\n  Message,\n)\n Create a new sharding manager with more control over the options, uses Client under the hood\nSynonyms:\nshimmer.new_sharded_with_opts\nshimmer new_sharded_with_opts","url":"shimmer.html#new_sharded_with_opts"},{"doc":"shimmer","title":"new_with_opts","content":"pub fn new_with_opts(token: String, opts: ClientOptions) -&gt; Client(\n  Message,\n)\n Create a new Shimmer Client with more control over the options\nSynonyms:\nshimmer.new_with_opts\nshimmer new_with_opts","url":"shimmer.html#new_with_opts"},{"doc":"shimmer","title":"update_all_shards_presence","content":"pub fn update_all_shards_presence(shards: ShardsManager(Message), presence: Presence) -&gt; ShardsManager(\n  Message,\n)\n Update the presence of every client managed by the shards manager, returns the client to be used for future operations\n &gt; **Note** you must call `connect` before calling this function and do-not know if it has succeeded\nSynonyms:\nshimmer.update_all_shards_presence\nshimmer update_all_shards_presence","url":"shimmer.html#update_all_shards_presence"},{"doc":"shimmer","title":"update_all_shards_presence_from_builder","content":"pub fn update_all_shards_presence_from_builder(shards: ShardsManager(\n    Message,\n  ), builder: PresenceBuilder) -&gt; Result(\n  ShardsManager(Message),\n  ShimmerError,\n)\n Update the presence of every client managed by the shards manager, returns the client to be used for future operations\n &gt; **Note** you must call `connect` before calling this function and do-not know if it has succeeded\n Builds the presence from the builder and calls `update_client_presence`\nSynonyms:\nshimmer.update_all_shards_presence_from_builder\nshimmer update_all_shards_presence_from_builder","url":"shimmer.html#update_all_shards_presence_from_builder"},{"doc":"shimmer","title":"update_client_presence","content":"pub fn update_client_presence(client: Client(Message), presence: Presence) -&gt; Client(\n  Message,\n)\n Update the presence of the client, returns the client to be used for future operations\n &gt; **Note** you must call `connect` before calling this function and do-not know if it has succeeded\nSynonyms:\nshimmer.update_client_presence\nshimmer update_client_presence","url":"shimmer.html#update_client_presence"},{"doc":"shimmer","title":"update_client_presence_from_builder","content":"pub fn update_client_presence_from_builder(client: Client(Message), builder: PresenceBuilder) -&gt; Result(\n  Client(Message),\n  ShimmerError,\n)\n Update the presence of the client, returns the client to be used for future operations\n &gt; **Note** you must call `connect` before calling this function and do-not know if it has succeeded\n Builds the presence from the builder and calls `update_client_presence`\nSynonyms:\nshimmer.update_client_presence_from_builder\nshimmer update_client_presence_from_builder","url":"shimmer.html#update_client_presence_from_builder"},{"doc":"shimmer","title":"shimmer","content":"","url":"shimmer.html"},{"doc":"shimmer/message","title":"send","content":"pub fn send(client: Client(Message), content: String, channel_id: String) -&gt; Result(\n  Bool,\n  ShimmerError,\n)\n\nSynonyms:\nshimmer/message.send\nshimmer/message send","url":"shimmer/message.html#send"},{"doc":"shimmer/message","title":"shimmer/message","content":"","url":"shimmer/message.html"}]);